@@ -9,8 +9,10 @@ module Numeric.Units.Dimensional.UnitNames.InterchangeNames
 )
 where
 
+import Control.DeepSeq
 import Data.Data
 import GHC.Generics
+import Prelude
 
 -- | Represents the authority which issued an interchange name for a unit.
 data InterchangeNameAuthority = UCUM -- ^ The interchange name originated with the Unified Code for Units of Measure.
@@ -18,9 +20,13 @@ data InterchangeNameAuthority = UCUM -- ^ The interchange name originated with t
                               | Custom -- ^ The interchange name originated with a user of the dimensional library.
   deriving (Eq, Ord, Show, Data, Typeable, Generic)
 
-data InterchangeName = InterchangeName { name :: String, authority :: InterchangeNameAuthority }
+instance NFData InterchangeNameAuthority where -- instance is derived from Generic instance
+
+data InterchangeName = InterchangeName { name :: String, authority :: InterchangeNameAuthority, isAtomic :: Bool }
   deriving (Eq, Ord, Data, Typeable, Generic)
 
+instance NFData InterchangeName where -- instance is derived from Generic instance
+
 instance Show InterchangeName where
   show n = name n ++ " (Issued by " ++ show (authority n) ++ ")"
 
