@@ -1,7 +1,6 @@
 {-# OPTIONS_HADDOCK not-home #-}
 
 {-# LANGUAGE AutoDeriveTypeable #-}
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveGeneric #-}
@@ -20,11 +19,7 @@ import Control.DeepSeq
 import Control.Monad (join)
 import Data.Coerce
 import Data.Data hiding (Prefix)
-#if MIN_VERSION_base(4, 8, 0)
 import Data.Foldable (toList)
-#else
-import Data.Foldable (Foldable, toList)
-#endif
 import Data.Ord
 import GHC.Generics hiding (Prefix)
 import Numeric.Units.Dimensional.Dimensions.TermLevel (Dimension', asList, HasDimension(..))
@@ -73,13 +68,14 @@ instance NFData (UnitName m) where
     Grouped n' -> rnf n'
     Weaken n' -> rnf n'
 
+-- | `UnitName`s are shown with non-breaking spaces.
 instance Show (UnitName m) where
   show One = "1"
   show (MetricAtomic a) = abbreviation_en a
   show (Atomic a) = abbreviation_en a
   show (Prefixed a n) = abbreviation_en a ++ show n
-  show (Product n1 n2) = show n1 ++ " " ++ show n2
-  show (Quotient n1 n2) = show n1 ++ " / " ++ show n2
+  show (Product n1 n2) = show n1 ++ "\xA0" ++ show n2
+  show (Quotient n1 n2) = show n1 ++ "\xA0/\xA0" ++ show n2
   show (Power x n) = show x ++ "^" ++ show n
   show (Grouped n) = "(" ++ show n ++ ")"
   show (Weaken n) = show n
@@ -87,11 +83,11 @@ instance Show (UnitName m) where
 asAtomic :: UnitName m -> Maybe (NameAtom ('UnitAtom m))
 asAtomic (MetricAtomic a) = Just a
 asAtomic (Atomic a) = Just a
-asAtomic (Weaken n) = fmap coerce $ asAtomic n
+asAtomic (Weaken n) = coerce <$> asAtomic n
 asAtomic _ = Nothing
 
 isAtomic :: UnitName m -> Bool
-isAtomic (One) = True
+isAtomic One = True
 isAtomic (MetricAtomic _) = True
 isAtomic (Atomic _) = True
 isAtomic (Prefixed _ _) = True
@@ -105,13 +101,13 @@ isAtomicOrProduct n = isAtomic n
 
 -- reduce by algebraic simplifications
 reduce :: UnitName m -> UnitName m
-reduce (One) = One
+reduce One = One
 reduce n@(MetricAtomic _) = n
 reduce n@(Atomic _) = n
 reduce n@(Prefixed _ _) = n
 reduce (Product n1 n2) = reduce' (reduce n1 * reduce n2)
 reduce (Quotient n1 n2) = reduce' (reduce n1 * reduce n2)
-reduce (Power n x) = reduce' ((reduce n) ^ x)
+reduce (Power n x) = reduce' (reduce n ^ x)
 reduce (Grouped n) = reduce' (Grouped (reduce n))
 reduce (Weaken n) = reduce' (Weaken (reduce n))
 
@@ -267,7 +263,7 @@ strengthen _ = Nothing
 -- strengthening or weakening if neccessary. Because it may not be possible to strengthen,
 -- the result is returned in a 'Maybe' wrapper.
 relax :: forall m1 m2.(Typeable m1, Typeable m2) => UnitName m1 -> Maybe (UnitName m2)
-relax n = go (typeRep (Proxy :: Proxy m1)) (typeRep (Proxy :: Proxy m2)) n
+relax = go (typeRep (Proxy :: Proxy m1)) (typeRep (Proxy :: Proxy m2))
   where
     metric = typeRep (Proxy :: Proxy 'Metric)
     nonMetric = typeRep (Proxy :: Proxy 'NonMetric)
@@ -313,14 +309,14 @@ instance HasInterchangeName (UnitName m) where
   -- TODO #109: note in this case that the UCUM is changing their grammar to not accept exponents after
   -- as a result it will become necessary to distribute the exponentiation over the items in the base name
   -- prior to generating the interchange name
-  interchangeName (Power n x) = let n' = (name . interchangeName $ n) ++ (show x)
+  interchangeName (Power n x) = let n' = (name . interchangeName $ n) ++ show x
                                  in InterchangeName { name = n', authority = authority . interchangeName $ n, I.isAtomic = False }
   interchangeName (Grouped n) = let n' = "(" ++ (name . interchangeName $ n) ++ ")"
                                  in InterchangeName { name = n', authority = authority . interchangeName $ n, I.isAtomic = False }
   interchangeName (Weaken n) = interchangeName n
 
 prefix :: String -> String -> String -> Rational -> Prefix
-prefix i a f q = Prefix n q
+prefix i a f = Prefix n
   where
     n = NameAtom (InterchangeName i UCUM True) a f
 
